# aigerox

[![Build Status](https://github.com/Lipen/aigerox/actions/workflows/ci.yml/badge.svg)](https://github.com/Lipen/aigerox/actions/workflows/ci.yml)

> A Rust library for working with AIGs (And-Inverted Graphs) and reading and writing AIGER files.
